Demonstration Notebooks
=======================

A collection of demonstration notebooks showcasing the use of community developed
lightcurve and activity classes.


Lightcurve Example Notebooks
----------------------------

.. NOTE: Please add new notebooks alphabetically
.. toctree::
    Sinusoidal Lightcurve <notebooks/lightcurve/sinusoidal/sinusoidal_example>

Activity Example Notebooks
--------------------------

.. NOTE: Please add new notebooks alphabetically
.. toctree:: 
    LSST Comet <notebooks/activity/lsst_comet/simple_cometary_magnitude>
